# Built from, with some modifications
# http://stackoverflow.com/questions/8919414/powershell-http-post-rest-api-basic-authentication
function Execute-HTTPPostCommand() {

  # Set up parameters and defaults
  param(
      [string] $target  = $null,
      [string] $user    = $null,
      [string] $pass    = $null,
      [string] $content = $null,
      [string] $verb    = "POST",
      [string] $ctype   = "application/json"
  )
   
  # Create the Basic auth header from the user/password
  $authHeader = 'Basic ' + [Convert]::ToBase64String([Text.Encoding]::ASCII.GetBytes( $user + ":" + $pass ))
 
  # Set headers and content type. Note that ContentType is a
  # property of the webRequest, not a header itself
  $webRequest = [System.Net.WebRequest]::Create($target)
  $webRequest.Headers.Add("Authorization", $authHeader)
  $webRequest.ContentType = $ctype
  $webRequest.Method = $verb
 
 
  try {
  
  # Pass the content? Not really sure what this does.
  $encodedContent = [System.Text.Encoding]::UTF8.GetBytes($content)
  if($encodedContent.length -gt 0) {
      
     $webRequest.ContentLength = $encodedContent.length
     $requestStream = $webRequest.GetRequestStream()
     $requestStream.Write($encodedContent, 0, $encodedContent.length)
     $requestStream.Close()
  }
 
  
    # Invoke the web service and capture the response
    [System.Net.WebResponse] $resp = $webRequest.GetResponse()
    
    "resp: " + $resp |  Out-File $LOG -encoding ASCII -Append
    
    
    
    # The WebResponse object isn't terribly useful in itself,
    # so we grab the stream and pass to a new variable
    $rs = $resp.GetResponseStream()
    [System.IO.StreamReader] $sr = New-Object System.IO.StreamReader -argumentList $rs
    [string] $results = $sr.ReadToEnd()
  }
  
  catch [System.Net.WebException] {
  
    #Write-Warning $_
    if ($_.response) {
      $_.response.Close();    
    }
    return $_.Exception.Message
  }

  finally {
    if ($sr) {
      $sr.close();
      $sr.dispose();
    }
    if ($resp) {
      $resp.close();
    }
  }
	
  
  
  return $results
}


# PS 2.0 doesn't have libraries for Json, so I found this one here:
# http://rkeithhill.wordpress.com/2009/12/06/json-serializationdeserialization-in-powershell/
function Convert-JsonToXml([string]$json)
{
  $bytes = [byte[]][char[]]$json
  $quotas = [System.Xml.XmlDictionaryReaderQuotas]::Max
  $jsonReader = [System.Runtime.Serialization.Json.JsonReaderWriterFactory]::CreateJsonReader($bytes,$quotas)
  try
  {
      $xml = new-object System.Xml.XmlDocument
  
      $xml.Load($jsonReader)
      $xml
  }
  finally
  {
      $jsonReader.Close()
  }
}