param(
  [string] $xM_Host     = $null,
  [string] $user       = $null,
  [string] $pass       = $null,
  [string] $scriptPath = "C:\Users\Administrator\Desktop\Crap",
  [string] $Assignee         = "None",
  [string] $Category         = "None",
  [string] $LastPublicUpdate = "None",
  [string] $Priority         = "None",
  [string] $Severity         = "None",
  [string] $Stage            = "None",
  [string] $Status           = "None",
  [string] $Summary          = "None",
  [string] $TicketId         = "None",
  [string] $TicketURL        = "None",
  [string] $xM_Group_Default = "Kaseya Service Desk"
  
)

# This is used by the JSON parsing function in the xMFunctions script
Add-Type -Assembly System.ServiceModel.Web,System.Runtime.Serialization

# Add debug info to the logs
$DEBUG = $true



. $scriptPath\xMFunctions.ps1
$LOG = $scriptPath + "\xM.log"

If ( $pass -eq '' ) {
  $temp = $scriptPath + "\xMPassword.txt"
  (Get-Date -Format g) + " Password empty, reading from config file: '" + $temp + "'" | Out-File $LOG -encoding ASCII -Append
  $pass = Get-Content $temp
}


If ( $Assignee -eq '' ) {
  (Get-Date -Format g) + " Assignee parameter empty, using '" + $xM_Group_Default + "'" | Out-File $LOG -encoding ASCII -Append
  $Assignee = $xM_Group_Default
}


# The assignee field contains either a user or a group
$recipient = $Assignee

$UNASSIGNED = "/reapi/2014-06-01/engines/Kaseya/Unassigned/events"
$ASSIGNED =    "/reapi/2014-06-01/engines/Kaseya/Assigned/events"
If ( $Assignee -eq '' ) { 
  $endpoint = $xM_Host + $UNASSIGNED 
}
Else { 
  $endpoint = $xM_Host + $ASSIGNED 
}


if( $DEBUG ) {
  (Get-Date -Format g) + " ==== Inputs: "                            | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " endpoint: " + $endpoint                   | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " User: " + $user                           | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " scriptPath: " + $scriptPath               | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " Assignee         = '" + $Assignee          + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " Category         = '" + $Category          + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " LastPublicUpdate = '" + $LastPublicUpdate  + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " Priority         = '" + $Priority          + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " Severity         = '" + $Severity          + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " Stage            = '" + $Stage             + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " Status           = '" + $Status            + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " Summary          = '" + $Summary           + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " TicketId         = '" + $TicketId          + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " TicketURL        = '" + $TicketURL         + "'" | Out-File $LOG -encoding ASCII -Append
  (Get-Date -Format g) + " xM_Group         = '" + $xM_Group          + "'" | Out-File $LOG -encoding ASCII -Append
}

$temp = $TicketURL -match "href='(.*?)'"
If ( $temp ) { $TicketURL = $matches[1] }



$content  = "{ `n"
$content += "`"properties`": {   `n"
$content += "  `"Assignee`": `"" + $Assignee + "`",`n" 
$content += "  `"Category`": `"" + $Category + "`",`n" 
$content += "  `"LastPublicUpdate`": `"" + $LastPublicUpdate + "`",`n" 
$content += "  `"Priority`": `"" + $Priority + "`",`n" 
$content += "  `"Severity`": `"" + $Severity + "`",`n" 
$content += "  `"Stage`": `"" + $Stage + "`",`n" 
$content += "  `"Status`": `"" + $Status + "`",`n" 
$content += "  `"Summary`": `"" + $Summary + "`",`n" 
$content += "  `"TicketId`": `"" + $TicketId + "`",`n" 
$content += "  `"TicketURL`": `"" + $TicketURL + "`",`n"
$content += "  `"xMURL`": `"" + $xM_Host + "`"`n"
$content += "}, `n"
$content += "`"recipients`": [ { `"targetName`": `"$recipient`" } ]`n"
$content += "}"


If ( $DEBUG ) {
  (Get-Date -Format g) + "  ==== Sending content: " + $content | Out-File $LOG -encoding ASCII -Append
}

$resp = Execute-HTTPPostCommand $endpoint $user $pass $content


(Get-Date -Format g) + "  ==== Received result for Ticket '" + $TicketId + "': " + $resp | Out-File $LOG -encoding ASCII -Append


# Inspect the result and see if there were any errors returned. 
if ( $resp.contains( "id" ) ) {
  $xml = Convert-JsonToXml $resp
  return $xml.root.id.'#text'
}
else {
  return "xERROR"
}